@@ -32,7 +32,6 @@
 #include <project/helper.h>
 
 #include <KColorScheme>
-#include <kio_version.h>
 
 #include <QDialogButtonBox>
 #include <QFileInfo>
@@ -50,7 +49,7 @@ MesonNewBuildDir::MesonNewBuildDir(IProject* project, QWidget* parent)
     Q_ASSERT(mgr); // This dialog only works with the MesonManager
 
     setWindowTitle(
-        i18n("Configure a build directory - %1", ICore::self()->runtimeController()->currentRuntime()->name()));
+        i18nc("@title:window", "Configure a Build Directory - %1", ICore::self()->runtimeController()->currentRuntime()->name()));
 
     m_ui = new Ui::MesonNewBuildDir;
     m_ui->setupUi(this);
@@ -63,11 +62,7 @@ MesonNewBuildDir::MesonNewBuildDir(IProject* project, QWidget* parent)
         }
     });
 
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 33, 0)
     m_ui->i_buildDir->setAcceptMode(QFileDialog::AcceptSave);
-#else
-    m_ui->i_buildDir->fileDialog()->setAcceptMode(QFileDialog::AcceptSave);
-#endif
 
     resetFields();
 }
