@@ -76,7 +76,7 @@ protected:
     //Initializes the style options from the index
     void initStyleOption(QStyleOptionViewItem* option, const QModelIndex& index) const;
 
-    mutable int m_currentColumnStart; //Text-offset for custom highlighting, will be applied to m_cachedHighlights(Only highlights starting after this will be used). Shoult be zero of the highlighting is not taken from kate.
+    mutable int m_currentColumnStart; //Text-offset for custom highlighting, will be applied to m_cachedHighlights(Only highlights starting after this will be used). Should be zero of the highlighting is not taken from kate.
     mutable QList<int> m_currentColumnStarts;
     mutable QVector<QTextLayout::FormatRange> m_cachedHighlights;
 
